@@ -300,316 +300,6 @@ my %sTimecode = (
     },
 );
 
-#------------------------------------------------------------------------------
-# PLUS (Picture Licensing Universal System)
-
-# PLUS vocabulary conversions
-my %plusVocab = (
-    ValueConv => '$val =~ s{http://ns.useplus.org/ldf/vocab/}{}; $val',
-    ValueConvInv => '"http://ns.useplus.org/ldf/vocab/$val"',
-);
-
-# PLUS License Data Format 1.2.1 structures
-# (this seems crazy to me -- why did they define different ID/Name structures
-#  for each field rather than just re-using the same structure?)
-my %plusLicensee = (
-    STRUCT_NAME => 'Licensee',
-    NAMESPACE => 'plus',
-    # all "rdf:type" properties removed in version 1.2.1
-    # (idiots.  Why did they put them there in the first place? -- it required
-    # a special patch for ExifTool to support these, and now they are gone!)
-  # TYPE => 'plus:LicenseeDetail', (removed in 1.2.1)
-    LicenseeID  => { },
-    LicenseeName=> { },
-);
-my %plusEndUser = (
-    STRUCT_NAME => 'EndUser',
-    NAMESPACE   => 'plus',
-  # TYPE => 'plus:EndUserDetail', (removed in 1.2.1)
-    EndUserID   => { },
-    EndUserName => { },
-);
-my %plusLicensor = (
-    STRUCT_NAME => 'Licensor',
-    NAMESPACE   => 'plus',
-  # TYPE => 'plus:LicensorDetail', (removed in 1.2.1)
-    LicensorID              => { },
-    LicensorName            => { },
-    LicensorStreetAddress   => { },
-    LicensorExtendedAddress => { },
-    LicensorCity            => { },
-    LicensorRegion          => { },
-    LicensorPostalCode      => { },
-    LicensorCountry         => { },
-    LicensorTelephoneType1  => {
-        %plusVocab,
-        PrintConv => {
-            'work'  => 'Work',
-            'cell'  => 'Cell',
-            'fax'   => 'FAX',
-            'home'  => 'Home',
-            'pager' => 'Pager',
-        },
-    },
-    LicensorTelephone1      => { },
-    LicensorTelephoneType2  => {
-        %plusVocab,
-        PrintConv => {
-            'work'  => 'Work',
-            'cell'  => 'Cell',
-            'fax'   => 'FAX',
-            'home'  => 'Home',
-            'pager' => 'Pager',
-        },
-    },
-    LicensorTelephone2  => { },
-    LicensorEmail       => { },
-    LicensorURL         => { },
-);
-my %plusCopyrightOwner = (
-    STRUCT_NAME => 'CopyrightOwner',
-    NAMESPACE   => 'plus',
-  # TYPE        => 'plus:CopyrightOwnerDetail', (removed in 1.2.1)
-    CopyrightOwnerID    => { },
-    CopyrightOwnerName  => { },
-);
-my %plusImageCreator = (
-    STRUCT_NAME => 'ImageCreator',
-    NAMESPACE   => 'plus',
-  # TYPE        => 'plus:ImageCreatorDetail', (removed in 1.2.1)
-    ImageCreatorID      => { },
-    ImageCreatorName    => { },
-);
-my %plusImageSupplier = (
-    STRUCT_NAME => 'ImageSupplier',
-    NAMESPACE   => 'plus',
-  # TYPE        => 'plus:ImageSupplierDetail', (removed in 1.2.1)
-    ImageSupplierID     => { },
-    ImageSupplierName   => { },
-);
-
-# PLUS License Data Format 1.2.0 (plus) (ref 1)
-%Image::ExifTool::XMP::plus = (
-    %xmpTableDefaults,
-    GROUPS => { 0 => 'XMP', 1 => 'XMP-plus', 2 => 'Author' },
-    NAMESPACE => 'plus',
-    NOTES => q{
-        PLUS License Data Format 1.2.1 namespace tags.  Note that all
-        controlled-vocabulary tags in this table (ie. tags with a fixed set of
-        values) have raw values which begin with "http://ns.useplus.org/ldf/vocab/",
-        but to reduce clutter this prefix has been removed from the values shown
-        below.  (see L<http://ns.useplus.org/>)
-    },
-    Version  => { Name => 'PLUSVersion' },
-    Licensee => {
-        FlatName => '',
-        Struct => \%plusLicensee,
-        List => 'Seq',
-    },
-    EndUser => {
-        FlatName => '',
-        Struct => \%plusEndUser,
-        List => 'Seq',
-    },
-    Licensor => {
-        FlatName => '',
-        Struct => \%plusLicensor,
-        List => 'Seq',
-    },
-    LicensorNotes               => { Writable => 'lang-alt' },
-    MediaSummaryCode            => { },
-    LicenseStartDate            => { %dateTimeInfo, Groups => { 2 => 'Time'} },
-    LicenseEndDate              => { %dateTimeInfo, Groups => { 2 => 'Time'} },
-    MediaConstraints            => { Writable => 'lang-alt' },
-    RegionConstraints           => { Writable => 'lang-alt' },
-    ProductOrServiceConstraints => { Writable => 'lang-alt' },
-    ImageFileConstraints => {
-        List => 'Bag',
-        %plusVocab,
-        PrintConv => {
-            'IF-MFN' => 'Maintain File Name',
-            'IF-MID' => 'Maintain ID in File Name',
-            'IF-MMD' => 'Maintain Metadata',
-            'IF-MFT' => 'Maintain File Type',
-        },
-    },
-    ImageAlterationConstraints => {
-        List => 'Bag',
-        %plusVocab,
-        PrintConv => {
-            'AL-CRP' => 'No Cropping',
-            'AL-FLP' => 'No Flipping',
-            'AL-RET' => 'No Retouching',
-            'AL-CLR' => 'No Colorization',
-            'AL-DCL' => 'No De-Colorization',
-            'AL-MRG' => 'No Merging',
-        },
-    },
-    ImageDuplicationConstraints => {
-        %plusVocab,
-        PrintConv => {
-            'DP-NDC' => 'No Duplication Constraints',
-            'DP-LIC' => 'Duplication Only as Necessary Under License',
-            'DP-NOD' => 'No Duplication',
-        },
-    },
-    ModelReleaseStatus => {
-        %plusVocab,
-        PrintConv => {
-            'MR-NON' => 'None',
-            'MR-NAP' => 'Not Applicable',
-            'MR-UMR' => 'Unlimited Model Releases',
-            'MR-LMR' => 'Limited or Incomplete Model Releases',
-        },
-    },
-    ModelReleaseID      => { List => 'Bag' },
-    MinorModelAgeDisclosure => {
-        %plusVocab,
-        PrintConv => {
-            'AG-UNK' => 'Age Unknown',
-            'AG-A25' => 'Age 25 or Over',
-            'AG-A24' => 'Age 24',
-            'AG-A23' => 'Age 23',
-            'AG-A22' => 'Age 22',
-            'AG-A21' => 'Age 21',
-            'AG-A20' => 'Age 20',
-            'AG-A19' => 'Age 19',
-            'AG-A18' => 'Age 18',
-            'AG-A17' => 'Age 17',
-            'AG-A16' => 'Age 16',
-            'AG-A15' => 'Age 15',
-            'AG-U14' => 'Age 14 or Under',
-        },
-    },
-    PropertyReleaseStatus => {
-        %plusVocab,
-        PrintConv => {
-            'PR-NON' => 'None',
-            'PR-NAP' => 'Not Applicable',
-            'PR-UPR' => 'Unlimited Property Releases',
-            'PR-LPR' => 'Limited or Incomplete Property Releases',
-        },
-    },
-    PropertyReleaseID  => { List => 'Bag' },
-    OtherConstraints   => { Writable => 'lang-alt' },
-    CreditLineRequired => {
-        %plusVocab,
-        PrintConv => {
-            'CR-NRQ' => 'Not Required',
-            'CR-COI' => 'Credit on Image',
-            'CR-CAI' => 'Credit Adjacent To Image',
-            'CR-CCA' => 'Credit in Credits Area',
-        },
-    },
-    AdultContentWarning => {
-        %plusVocab,
-        PrintConv => {
-            'CW-NRQ' => 'Not Required',
-            'CW-AWR' => 'Adult Content Warning Required',
-            'CW-UNK' => 'Unknown',
-        },
-    },
-    OtherLicenseRequirements    => { Writable => 'lang-alt' },
-    TermsAndConditionsText      => { Writable => 'lang-alt' },
-    TermsAndConditionsURL       => { },
-    OtherConditions             => { Writable => 'lang-alt' },
-    ImageType => {
-        %plusVocab,
-        PrintConv => {
-            'TY-PHO' => 'Photographic Image',
-            'TY-ILL' => 'Illustrated Image',
-            'TY-MCI' => 'Multimedia or Composited Image',
-            'TY-VID' => 'Video',
-            'TY-OTR' => 'Other',
-        },
-    },
-    LicensorImageID     => { },
-    FileNameAsDelivered => { },
-    ImageFileFormatAsDelivered => {
-        %plusVocab,
-        PrintConv => {
-            'FF-JPG' => 'JPEG Interchange Formats (JPG, JIF, JFIF)',
-            'FF-TIF' => 'Tagged Image File Format (TIFF)',
-            'FF-GIF' => 'Graphics Interchange Format (GIF)',
-            'FF-RAW' => 'Proprietary RAW Image Format',
-            'FF-DNG' => 'Digital Negative (DNG)',
-            'FF-EPS' => 'Encapsulated PostScript (EPS)',
-            'FF-BMP' => 'Windows Bitmap (BMP)',
-            'FF-PSD' => 'Photoshop Document (PSD)',
-            'FF-PIC' => 'Macintosh Picture (PICT)',
-            'FF-PNG' => 'Portable Network Graphics (PNG)',
-            'FF-WMP' => 'Windows Media Photo (HD Photo)',
-            'FF-OTR' => 'Other',
-        },
-    },
-    ImageFileSizeAsDelivered => {
-        %plusVocab,
-        PrintConv => {
-            'SZ-U01' => 'Up to 1 MB',
-            'SZ-U10' => 'Up to 10 MB',
-            'SZ-U30' => 'Up to 30 MB',
-            'SZ-U50' => 'Up to 50 MB',
-            'SZ-G50' => 'Greater than 50 MB',
-        },
-    },
-    CopyrightStatus => {
-        %plusVocab,
-        PrintConv => {
-            'CS-PRO' => 'Protected',
-            'CS-PUB' => 'Public Domain',
-            'CS-UNK' => 'Unknown',
-        },
-    },
-    CopyrightRegistrationNumber => { },
-    FirstPublicationDate        => { %dateTimeInfo, Groups => { 2 => 'Time'} },
-    CopyrightOwner => {
-        FlatName => '',
-        Struct => \%plusCopyrightOwner,
-        List => 'Seq',
-    },
-    CopyrightOwnerImageID   => { },
-    ImageCreator => {
-        FlatName => '',
-        Struct => \%plusImageCreator,
-        List => 'Seq',
-    },
-    ImageCreatorImageID     => { },
-    ImageSupplier => {
-        FlatName => '',
-        Struct => \%plusImageSupplier,
-        List => 'Seq',
-    },
-    ImageSupplierImageID    => { },
-    LicenseeImageID         => { },
-    LicenseeImageNotes      => { Writable => 'lang-alt' },
-    OtherImageInfo          => { Writable => 'lang-alt' },
-    LicenseID               => { },
-    LicensorTransactionID   => { List => 'Bag' },
-    LicenseeTransactionID   => { List => 'Bag' },
-    LicenseeProjectReference=> { List => 'Bag' },
-    LicenseTransactionDate  => { %dateTimeInfo, Groups => { 2 => 'Time'} },
-    Reuse => {
-        %plusVocab,
-        PrintConv => {
-            'RE-REU' => 'Repeat Use',
-            'RE-NAP' => 'Not Applicable',
-        },
-    },
-    OtherLicenseDocuments   => { List => 'Bag' },
-    OtherLicenseInfo        => { Writable => 'lang-alt' },
-    # Note: these are Bag's of lang-alt lists -- a nested list tag!
-    Custom1     => { List => 'Bag', Writable => 'lang-alt' },
-    Custom2     => { List => 'Bag', Writable => 'lang-alt' },
-    Custom3     => { List => 'Bag', Writable => 'lang-alt' },
-    Custom4     => { List => 'Bag', Writable => 'lang-alt' },
-    Custom5     => { List => 'Bag', Writable => 'lang-alt' },
-    Custom6     => { List => 'Bag', Writable => 'lang-alt' },
-    Custom7     => { List => 'Bag', Writable => 'lang-alt' },
-    Custom8     => { List => 'Bag', Writable => 'lang-alt' },
-    Custom9     => { List => 'Bag', Writable => 'lang-alt' },
-    Custom10    => { List => 'Bag', Writable => 'lang-alt' },
-);
-
 #------------------------------------------------------------------------------
 # PRISM
 #
@@ -1168,9 +858,13 @@ my %sSubVersion = (
     %xmpTableDefaults,
     GROUPS => { 1 => 'XMP-xmpPLUS', 2 => 'Author' },
     NAMESPACE => 'xmpPLUS',
-    NOTES => 'XMP Picture Licensing Universal System (PLUS) namespace tags.',
-    CreditLineReq   => { Writable => 'boolean' },
-    ReuseAllowed    => { Writable => 'boolean' },
+    NOTES => q{
+        XMP Picture Licensing Universal System (PLUS) tags as written by some older
+        Adobe applications.  See L<PLUS XMP Tags|Image::ExifTool::TagNames/PLUS XMP Tags>
+        for the current PLUS tags.
+    },
+    CreditLineReq   => { Writable => 'boolean', Avoid => 1 },
+    ReuseAllowed    => { Writable => 'boolean', Avoid => 1 },
 );
 
 # Creative Commons namespace properties (cc) (ref 5)
@@ -1458,25 +1152,25 @@ my %sSubVersion = (
     PoseHeadingDegrees              => { Writable => 'real' },
     PosePitchDegrees                => { Writable => 'real' },
     PoseRollDegrees                 => { Writable => 'real' },
-    InitialViewHeadingDegrees       => { Writable => 'integer' },
-    InitialViewPitchDegrees         => { Writable => 'integer' },
-    InitialViewRollDegrees          => { Writable => 'integer' },
+    InitialViewHeadingDegrees       => { Writable => 'real' },
+    InitialViewPitchDegrees         => { Writable => 'real' },
+    InitialViewRollDegrees          => { Writable => 'real' },
     InitialHorizontalFOVDegrees     => { Writable => 'real' },
     FirstPhotoDate                  => { %dateTimeInfo, Groups => { 2 => 'Time' } },
     LastPhotoDate                   => { %dateTimeInfo, Groups => { 2 => 'Time' } },
     SourcePhotosCount               => { Writable => 'integer' },
     ExposureLockUsed                => { Writable => 'boolean' },
-    CroppedAreaImageWidthPixels     => { Writable => 'integer' },
-    CroppedAreaImageHeightPixels    => { Writable => 'integer' },
-    FullPanoWidthPixels             => { Writable => 'integer' },
-    FullPanoHeightPixels            => { Writable => 'integer' },
-    CroppedAreaLeftPixels           => { Writable => 'integer' },
-    CroppedAreaTopPixels            => { Writable => 'integer' },
+    CroppedAreaImageWidthPixels     => { Writable => 'real' },
+    CroppedAreaImageHeightPixels    => { Writable => 'real' },
+    FullPanoWidthPixels             => { Writable => 'real' },
+    FullPanoHeightPixels            => { Writable => 'real' },
+    CroppedAreaLeftPixels           => { Writable => 'real' },
+    CroppedAreaTopPixels            => { Writable => 'real' },
     # (the following have been observed, but are not in the specification)
-    LargestValidInteriorRectLeft    => { Writable => 'integer' },
-    LargestValidInteriorRectTop     => { Writable => 'integer' },
-    LargestValidInteriorRectWidth   => { Writable => 'integer' },
-    LargestValidInteriorRectHeight  => { Writable => 'integer' },
+    LargestValidInteriorRectLeft    => { Writable => 'real' },
+    LargestValidInteriorRectTop     => { Writable => 'real' },
+    LargestValidInteriorRectWidth   => { Writable => 'real' },
+    LargestValidInteriorRectHeight  => { Writable => 'real' },
 );
 
 # Getty Images namespace (ref PH)
